@@ -4,7 +4,7 @@ use 5.008008;
 use strict;
 use warnings;
 
-our $VERSION = '2.1';
+our $VERSION = '2.2';
 
 use Text::Sentence qw( split_sentences );
 use Lingua::NegEx qw( negation_scope );
@@ -210,24 +210,35 @@ Negated terms are identified using Lingua::NegEx which is a perl implementation
 Define your extraction rules:
 
 1. Choose your target phrases that describe the condition of interest.
+
 2. Choose any skip phrases that will eliminate a sentence from an analysis if the phrase exists. For example, many radiology reports may have a sentence that states the indication for the study which might state the condition you are looking for but doesn't indicate that the condition was found in the study.
+
 3. Choose any absolute present phrases to use which are phrases that if they are present in the text mean the condition is certainly there and all ambiguity checking can be skipped.
+
 4. Choose any absolute negative phrases that mean the condition is absolutely not present and all ambiguity checking can be skipped.
+
 5. Choose a start phrase which can be used to focus the search to only the text that occurs after this start phrase. For example, if there is an 'Impression:' section at the end of a report that summarizes findings then skip to that section to avoid possible ambiguity generated by the verbose description of findings in the full report.
 	
-Only the target phrases are required.
+* Only the target phrases are required.
 	
 Once defined the extractor object you created can be used to analyze target text. The analysis consists of:
 
 1. If there is a start phrase defined, eliminate all text for analysis prior to the start phrase.
+
 2. Change all colons ':' into periods '.' to treat them as sentence breaks
+
 3. Split text into sentences using Text::Sentence
+
 4. Examine each sentence for the presence of any skip phrases and if found, ignore the sentence.
+
 5. Examine each sentence for the presence of any target phrases and if found evaluate for negation using Lingua:Negex.
- -if no negation found, mark this sentence as 'present'
- -if the target phrase is negated then mark the sentence as 'absent'
+  if no negation found, mark this sentence as 'present'
+  if the target phrase is negated then mark the sentence as 'absent'
+
 6. Go through all the flagged sentences and see if there is any discrepancy -- if so set the ambiguous flag. If there are more sentences that indicate absent than those that indicate present then mark the final answer as absent and vice versa. If there are an equal number of absent and present phrases mark the final answer as present.
-	
+
+7. The possible values for ambiguous: 1 = there were some positive and some absent sentences; 2 = there was a match on an absolute positive phrase but the answer was going to be absent had this absolute phrase not been indicated; 3 = there was a match on an absolute negative phrase but the answer was going to be present had this absolute phrase not been indicated;
+
 =head2 EXPORT
 
 None by default.
